summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/mapgen.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/mapgen.cpp b/src/mapgen.cpp
index b37d03501..67e92f449 100644
--- a/src/mapgen.cpp
+++ b/src/mapgen.cpp
@@ -1761,8 +1761,9 @@ void make_block(BlockMakeData *data)
vmanip.m_data[i] = airnode;
}
} else {
- // Don't replace air or water or lava
- if(vmanip.m_data[i].getContent() == CONTENT_AIR ||
+ // Don't replace air or water or lava or ignore
+ if(vmanip.m_data[i].getContent() == CONTENT_IGNORE ||
+ vmanip.m_data[i].getContent() == CONTENT_AIR ||
vmanip.m_data[i].getContent() == c_water_source ||
vmanip.m_data[i].getContent() == c_lava_source)
continue;